# Verifiable Credential Bitstring Status List context _(@digitalbazaar/vc-bitstring-status-list-context)_

[![Build status](https://img.shields.io/github/actions/workflow/status/digitalbazaar/vc-bitstring-status-list-context/main.yaml)](https://github.com/digitalbazaar/vc-bitstring-status-list-context/actions/workflow/main.yaml)
[![NPM Version](https://img.shields.io/npm/v/@digitalbazaar/vc-bitstring-status-list-context.svg)](https://npm.im/@digitalbazaar/vc-bitstring-status-list-context)

> A Verifiable Credential Bitstring Status List JSON-LD context for JavaScript.

## Table of Contents

- [Background](#background)
- [Install](#install)
- [Usage](#usage)
- [API](#api)
- [Status](#status)
- [Developing](#developing)
- [Commercial Support](#commercial-support)
- [License](#license)

## Background

This context includes the Verifiable Credentials Bitstring Status List related
data. Some use cases where this may be useful are:

* When the full Verifiable Credentials Data Model 2.0 context is not needed or
  used.
* When using the bitstring status list with Verifiable Credentials Data Model
  1.0.

See also (related specs):

* Verifiable Credentials Data Model 2.0
  * https://www.w3.org/TR/vc-data-model-2.0/
  * https://www.w3.org/ns/credentials/v2
  * https://github.com/w3c/vc-data-model/
  * https://github.com/digitalbazaar/credentials-v2-context
* Verifiable Credential Bitstring Status List
  * Independent spec for use outside of VCDM 2.0.
  * https://github.com/w3c/vc-bitstring-status-list
  * https://www.w3.org/ns/credentials/status/v1
* Verifiable Credential Status List 2021
  * Previous spec name, implementation, and context.
  * https://github.com/digitalbazaar/vc-status-list
  * https://github.com/digitalbazaar/vc-status-list-context

## Install

- Requires Node.js 18+

To install via NPM:

```
npm install @digitalbazaar/vc-bitstring-status-list-context
```

## Usage

```js
// ESM
import {
  CONTEXT,
  CONTEXT_URL,
  constants,
  context
} from '@digitalbazaar/vc-bitstring-status-list-context';

// CommonJS
const ctx = require('@digitalbazaar/vc-bitstring-status-list-context');
const {
  CONTEXT,
  CONTEXT_URL,
  constants,
  context
} = ctx;

// Default context URL
CONTEXT_URL
// -> 'https://www.w3.org/ns/credentials/status/v1'

// Default context data
CONTEXT
// -> full context object

// Codec term map value for CBOR-LD
constants.CBORLD_VALUE
// -> 0x0

// get context data for a specific context
const data = contexts.get('https://www.w3.org/ns/credentials/status/v1');
```

This package can be used with bundlers, such as [webpack][], in browser
applications.

## API

The library exports the following properties:
- `CONTEXT_URL`: Default context URL.
- `CONTEXT`: Default context data.
- `CBORLD_VALUE`: Default codec term map value for [CBOR-LD][].
- `constants`: A Object that maps constants to well-known context URLs. The
  main constant `CONTEXT_URL` may be updated from time to time to the
  latest context location.
- `contexts`: A `Map` that maps all context URLs to full context data.
- `appContextMap`: For use with the [cborld][] library.

## Status

- The context tracks the latest VC Data Model 2.0 context, which is currently
  under development.

## Developing

Source is available at:
- https://github.com/digitalbazaar/vc-bitstring-status-list-context

**WARNING**: The `.jsonld` in `contexts/` is auto-generated by the `npm run build` script,
each time you run the test suite.

DO NOT edit it directly (or your changes will be quickly overwritten).
Instead, make all context changes to `js/context.js`.

## Commercial Support

Commercial support for this library is available upon request from
Digital Bazaar: support@digitalbazaar.com

## License

- BSD 3-Clause © Digital Bazaar
- See the [LICENSE](./LICENSE) file for details.

[CBOR-LD]: https://digitalbazaar.github.io/cbor-ld-spec/
[cborld]: https://github.com/digitalbazaar/cborld
[webpack]: https://webpack.js.org/
